# FCL: 联邦持续学习 (Federated Continual Learning)

场景：联邦学习中的增量学习，防止灾难性遗忘

## 论文列表

- **fot** - FOT: Federated Orthogonal Training (NeurIPS 2022)
- **glfc** - GLFC: Global-Local Forgetting Compensation (CVPR 2022)
- **target** - TARGET: Exemplar-Free Distillation (ICCV 2023)
- **fedknow** - FedKNOW: Signature Task Knowledge Integration (INFOCOM 2023)
- **fed_cprompt** - Fed-CPrompt: Contrastive Prompt (CVPR 2023)
- **lga** - LGA: Layerwise Gradient Accumulation (TPAMI 2023)

## 特点

- 解决类别增量学习 (Class-Incremental Learning) 问题
- 防止学习新任务时遗忘旧任务
- 方法包括：正交投影、知识蒸馏、原型学习、提示学习等
